Protwarbar = LibStub("AceAddon-3.0"):NewAddon("Protwarbar", "AceEvent-3.0", "AceConsole-3.0", "AceTimer-3.0")

PWBRagebar = Protwarbar:NewModule("Ragebar", "AceEvent-3.0")
PWBInfo = Protwarbar:NewModule("Info", "AceEvent-3.0")
PWBIcon = Protwarbar:NewModule("PWBIcon", "AceEvent-3.0")
PWBAuraBar = Protwarbar:NewModule("PWBAuraBar", "AceEvent-3.0", "AceTimer-3.0")
PWBAnnounce = Protwarbar:NewModule("PWBAnnounce", "AceEvent-3.0")
PWBLog = Protwarbar:NewModule("PWBLog", "AceEvent-3.0", "AceTimer-3.0")
PWBShieldbar = Protwarbar:NewModule("PWBShieldbar", "AceEvent-3.0", "AceTimer-3.0")

local L = LibStub("AceLocale-3.0"):GetLocale("Protwarbar")

function Protwarbar:OnInitialize()
	Protwarbar:SetDefaultMedia()
	Protwarbar:CreateOptionsTables()

	self.db.RegisterCallback(self, "OnProfileChanged", "ProfileChanged")
	self.db.RegisterCallback(self, "OnProfileCopied", "ProfileChanged")
	self.db.RegisterCallback(self, "OnProfileReset", "ProfileChanged")

	Protwarbar:RegisterChatCommand('protwarbar', 'OnCommand')

	self.combat = false
end

function Protwarbar:CreateOptionsTables()
	defaults = self:CreateDefaults()
	defaults.profile.PWBAuraBar = PWBAuraBar:CreateDefaults()
	defaults.profile.PWBIcon = PWBIcon:CreateDefaults()
	defaults.profile.PWBInfo = PWBInfo:CreateDefaults()
	defaults.profile.PWBRagebar = PWBRagebar:CreateDefaults()
	defaults.profile.PWBAnnounce = PWBAnnounce:CreateDefaults()
	defaults.profile.PWBLog = PWBLog:CreateDefaults()
	defaults.profile.PWBShieldbar = PWBShieldbar:CreateDefaults()

	self.db = LibStub('AceDB-3.0'):New('ProtwarbarDB', defaults, true)
	self.profileOptions = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db);

	AceConfig = LibStub("AceConfigDialog-3.0")

	LibStub("AceConfig-3.0"):RegisterOptionsTable("Protwarbar", self:CreateOptions())
	AceConfig:AddToBlizOptions("Protwarbar", "Protwarbar")

	LibStub("AceConfig-3.0"):RegisterOptionsTable("PWBProfiles", self.profileOptions);
	AceConfig:AddToBlizOptions("PWBProfiles", L["Profile"], "Protwarbar");

end

function Protwarbar:ProfileChanged()
	Protwarbar:GetActiveTalents()
	self:SendMessage("PWB_PROFILE_CHANGED")
	Protwarbar:RefreshConfig()
end

function Protwarbar:OnCommand(input)
	if not input or input:trim() == "" then
		InterfaceOptionsFrame_OpenToCategory("Protwarbar")
	else
		if input:trim() == "lock" then
			Protwarbar.db.profile.locked = true
		elseif input:trim() == "unlock" then
			Protwarbar.db.profile.locked = false
		elseif input:trim() == "toggle" then
			Protwarbar.db.profile.locked = not Protwarbar.db.profile.locked
		else
			Protwarbar:Print(L["Use /protwarbar lock | unlock | toggle"])
		end

		Protwarbar:RefreshConfig()
	end
end

function Protwarbar:OnEnable()
	self.spec = GetSpecialization()
	Protwarbar:GetActiveTalents()

	local _, playerClass = UnitClass("player")

	if playerClass ~= "WARRIOR" then
		Protwarbar:Print(L["Protwarbar has been loaded but not enabled. Player class is not supported."])
		return
	end

	self.abilities = Protwarbar:LoadWarriorAbilities()

	if self.abilities ~= nil then
		self:SendMessage("PWB_ABILITIES_LOADED", self.abilities)
	end

	Protwarbar:InitProtwarbar()
	Protwarbar:LoadSelectedProfile()
	self:SendMessage("PWB_MODULE_ENABLE")
	Protwarbar:RefreshConfig()

end

function Protwarbar:InitProtwarbar()
	self:RegisterEvent("PLAYER_REGEN_DISABLED")
	self:RegisterEvent("PLAYER_REGEN_ENABLED")
	self:RegisterEvent("ACTIVE_TALENT_GROUP_CHANGED")
	self:RegisterEvent("PLAYER_TALENT_UPDATE")
end

function Protwarbar:RefreshConfig()
	self:SendMessage("PWB_REFRESH_CONFIG")
end

function Protwarbar:UpdateVisiblity()
	self:SendMessage("PWB_UPDATE_VISIBILITY")
end

function Protwarbar:OnDisable()
end

function Protwarbar:IsVisible()
	-- temp workaround
	local _, playerClass = UnitClass("player")
	if playerClass ~= "WARRIOR" then
		return false
	end

	if self.db.profile.enabled == false then
		return false
	end

	if self.db.profile.hideooc == true then
		if self.combat == true then
			return true
		else
			return false
		end
	end

	return true
end

function Protwarbar:LoadSelectedProfile()
	local profiles = self.db:GetProfiles()
	local spec = GetSpecialization()
	local preset = self.db.global.autoload[spec]

	if self.db.global.autoloadEnabled then
		if preset ~= nil then
			if Protwarbar:getProfileId(profiles, preset) ~= nil then
				Protwarbar:Print(L["Loading Profile: "] .. preset)
				self.db:SetProfile(preset)
				self:SendMessage("PWB_PROFILE_CHANGED")
			else
				Protwarbar:Print(L["Can not auto load profile:"] .. " '" .. preset .. "'.")
			end
		end
	end
end

-- start combat
function Protwarbar:PLAYER_REGEN_DISABLED()
	self.combat = true
	Protwarbar:UpdateVisiblity()
end

-- end combat
function Protwarbar:PLAYER_REGEN_ENABLED()
	self.combat = false
	Protwarbar:UpdateVisiblity()
end

function Protwarbar:ACTIVE_TALENT_GROUP_CHANGED()
	self.spec = GetSpecialization()
	Protwarbar:GetActiveTalents()
	Protwarbar:LoadSelectedProfile()
	Protwarbar:RefreshConfig()
end

function Protwarbar:PLAYER_TALENT_UPDATE()
	Protwarbar:GetActiveTalents()
	Protwarbar:RefreshConfig()
end

function Protwarbar:GetActiveTalents()
	self.talents = {}
	local numTalents = GetNumTalents(3)
	for i = 1, numTalents do
		local _, _, _, _, selected, _ = GetTalentInfo(i)
		self.talents[i] = selected
	end
end

function Protwarbar:UNIT_INVENTORY_CHANGED(eventName, unit)
	-- if (unit == "player") then
	-- 	Protwarbar:TrinketUpdateActiveTrinkets()
	-- 	Protwarbar:UpdateTrinketIcons()
	-- end
end