local media = LibStub("LibSharedMedia-3.0")

function Protwarbar:GetStyle(localStyle)

	local style = nil

	if localStyle.useDefaults then
		style = Protwarbar.db.profile.default.appearence
	else
		style = localStyle

		if style.shadowColor == nil then
			style.shadowColor = Protwarbar.db.profile.default.appearence.shadowColor
		end

		if style.shadowX == nil then
			style.shadowX = Protwarbar.db.profile.default.appearence.shadowX
		end

		if style.shadowY == nil then
			style.shadowY = Protwarbar.db.profile.default.appearence.shadowY
		end

		if style.textOffset == nil then
			style.textOffset = 0
		end

	end

	return style
end


function Protwarbar:UpdateFrame(frame, settings, options)
	if options == nil then
		options = {}
	end

	local scale = Protwarbar.db.profile.default.appearence.scale

	if options.halfsize == true then
		frame:SetWidth(settings.width * scale / 2)
	else
		frame:SetWidth(settings.width * scale)
	end

	local hscale = options.heightScale or 1
	frame:SetHeight(settings.height * hscale * scale)


	frame:SetMovable(not Protwarbar.db.profile.locked)
	frame:EnableMouse(not Protwarbar.db.profile.locked)
	frame:SetPoint("BOTTOMLEFT", settings.x, settings.y)
end


function Protwarbar:CreateTextField(frame, settings, options)
	if options == nil then
		options = {}
	end

	local style = Protwarbar:GetStyle(settings)

	textField = frame:CreateFontString(nil, "OVERLAY")
	textField:SetPoint("CENTER", frame, 0, 0);

	-- TODO check if we need offset on justify == center
	if options.halfsize == true then
		textField:SetSize(settings.width / 2 - style.textOffset , settings.height)
	else
		textField:SetSize(settings.width - style.textOffset, settings.height)
	end
	textField:SetSize(settings.width, settings.height)
	textField:SetFont(media:Fetch("font", style.font), style.fontsize, "OUTLINE")

	if options.justify ~= nil then
		textField:SetJustifyH(options.justify)
	end

	textField:SetText("")

	return textField

end

function Protwarbar:UpdateTextField(frame, settings, options)
	if options == nil then
		options = {}
	end

	local style = Protwarbar:GetStyle(settings)

	if options.halfsize == true then
		frame:SetSize(settings.width / 2 - style.textOffset, settings.height)
	else
		frame:SetSize(settings.width - style.textOffset, settings.height)
	end

	if style.outline then
		frame:SetFont(media:Fetch("font", style.font), style.fontsize, "OUTLINE")
		frame:SetShadowOffset(0, 0)
	else
		frame:SetFont(media:Fetch("font", style.font), style.fontsize)
		frame:SetShadowColor(style.shadowColor[1], style.shadowColor[2], style.shadowColor[3], style.shadowColor[4])
		frame:SetShadowOffset(style.shadowX, style.shadowY)
	end

end


function Protwarbar:UpdateStatusBar(frame, color, settings)
	local style = Protwarbar:GetStyle(settings)
	local scale = Protwarbar.db.profile.default.appearence.scale

	frame:SetStatusBarTexture(media:Fetch("statusbar", style.barTexture))
	frame:SetOrientation(style.orientation)
	frame:SetReverseFill(style.reverse)

	if color ~= nil then
		frame:SetStatusBarColor(color[1], color[2], color[3], color[4])
	end

	frame:SetWidth(settings.width * scale)
	frame:SetHeight(settings.height * scale)
	frame:SetPoint("BOTTOMLEFT", 0, 0)

end

function Protwarbar:UpdateBackdropColor(frame, settings, key, options)
	if options == nil then
		options = {}
	end

	local style = Protwarbar:GetStyle(settings)

	local color = {0,0,0,0}

	if not options.hidden then
		color = style[key]
	end

	if Protwarbar.db.profile.locked or options.hidden then
		frame:SetBackdropColor(color[1], color[2],color[3], color[4])
	else
		frame:SetBackdropColor(Protwarbar.db.profile.default.appearence.unlockbg[1],
			Protwarbar.db.profile.default.appearence.unlockbg[2],
			Protwarbar.db.profile.default.appearence.unlockbg[3],
			Protwarbar.db.profile.default.appearence.unlockbg[4])
	end
end


