local media = LibStub("LibSharedMedia-3.0")

function PWBIcon:createIcon(ability, id)
	frame = CreateFrame("Frame", nil, UIParent)
	frame:SetFrameStrata("BACKGROUND")
	frame:SetPoint("BOTTOMLEFT", self.db.icons[id].x, self.db.icons[id].y)

	-- icon frame movement
	frame:RegisterForDrag('LeftButton')
	frame:SetClampedToScreen(true)
	frame:SetScript("OnDragStart", function(self) PWBIcon:Dragstart(self) end )
	frame:SetScript('OnDragStop', function(self) PWBIcon:Dragstop(self) end )

	-- ability texture
	frame.texture = frame:CreateTexture(nil, "BACKGROUND")
	frame.texture:SetPoint("CENTER")
	frame.texture:SetTexture(GetSpellTexture(id))

	return frame
end

function PWBIcon:UpdateIconStyling(id)
	local style = nil

	if self.db.icons[id].useDefaults == false then
		style = self.db.icons[id]

		if style.iconsize == nil then
			style.iconsize = Protwarbar.db.profile.default.appearence.iconsize
		end

		if style.textureSize == nil then
			style.textureSize = Protwarbar.db.profile.default.appearence.textureSize
		end

		if style.background == nil then
			style.background = Protwarbar.db.profile.default.appearence.background
		end

		if style.edgeSize == nil then
			style.edgeSize = Protwarbar.db.profile.default.appearence.edgeSize
		end

		if style.border == nil then
			style.border = Protwarbar.db.profile.default.appearence.border
		end
	else
		style = Protwarbar.db.profile.default.appearence
	end

	local scale = Protwarbar.db.profile.default.appearence.scale

	self.iconFrames[id]:SetWidth(style.iconsize * scale)
	self.iconFrames[id]:SetHeight(style.iconsize * scale)
	self.iconFrames[id]:SetMovable(not Protwarbar.db.profile.locked)
	self.iconFrames[id]:EnableMouse(not Protwarbar.db.profile.locked)
	self.iconFrames[id]:SetPoint("BOTTOMLEFT", self.db.icons[id].x, self.db.icons[id].y)
	self.iconFrames[id]:SetBackdrop({bgFile = media:Fetch("background", "None"),
												edgeFile = media:Fetch("border", style.border),
			                                    tile = false, edgeSize = style.edgeSize})
	self.iconFrames[id].texture:SetWidth(style.textureSize * scale)
	self.iconFrames[id].texture:SetHeight(style.textureSize * scale)

	if Protwarbar.db.profile.locked then
		self.iconFrames[id]:SetBackdropColor(style.background[1], style.background[2], style.background[3], style.background[4])
	else
		self.iconFrames[id]:SetBackdropColor(Protwarbar.db.profile.default.appearence.unlockbg[1],
			Protwarbar.db.profile.default.appearence.unlockbg[2],
			Protwarbar.db.profile.default.appearence.unlockbg[3],
			Protwarbar.db.profile.default.appearence.unlockbg[4])
		self.iconFrames[id].texture:SetAlpha(1)
	end
end

function PWBIcon:UpdateIconVisiblity(id)

	local visible = self.db.icons[id].enabled and self.db.enabled and Protwarbar:IsVisible()
	local active = true

	if self.iconList[id].talent ~= nil then
		active = Protwarbar.talents[self.iconList[id].talent]
	end

	if visible and active then
		self.iconFrames[id]:Show()
	else
		self.iconFrames[id]:Hide()
	end

end

function PWBIcon:UpdateStyling()
	for id, ability in pairs(self.iconList) do
		PWBIcon:UpdateIconStyling(id)
	end
end

function PWBIcon:UpdateVisiblity()

	for id, ability in pairs(self.iconList) do
		PWBIcon:UpdateIconVisiblity(id)
	end

end

function PWBIcon:Dragstart(frame)
	if not Protwarbar.db.profile.locked then
		frame:StartMoving()
	end
end

function PWBIcon:Dragstop(frame)
	frame:StopMovingOrSizing()

	for id, ability in pairs(self.iconList) do
		self.db.icons[id].x = self.iconFrames[id]:GetLeft()
		self.db.icons[id].y = self.iconFrames[id]:GetBottom()

		PWBIcon:UpdateIconStyling(id)
	end

end